@@ -37,7 +37,7 @@ sub run {
   my ($self, $app) = @_;
 
   # No Windows support
-  _exit('Hypnotoad not available for Windows.') if $^O eq 'MSWin32';
+  _exit('Hypnotoad is not available for Windows.') if $^O eq 'MSWin32';
 
   # Remember executable and application for later
   $ENV{HYPNOTOAD_EXE} ||= $0;
@@ -102,7 +102,7 @@ sub _hot_deploy {
 sub _manage {
   my $self = shift;
 
-  # Upgraded
+  # Upgraded (wait for all workers to send a heartbeat)
   my $prefork = $self->prefork;
   my $log     = $prefork->app->log;
   if ($ENV{HYPNOTOAD_PID} && $ENV{HYPNOTOAD_PID} ne $$) {
@@ -389,7 +389,9 @@ Number of worker processes, defaults to the value of
 L<Mojo::Server::Prefork/"workers">. A good rule of thumb is two worker
 processes per CPU core for applications that perform mostly non-blocking
 operations, blocking operations often require more and benefit from decreasing
-the number of concurrent L</"clients"> (often as low as C<1>).
+the number of concurrent L</"clients"> (often as low as C<1>). Note that
+during zero downtime software upgrades there will be twice as many workers
+active for a short amount of time.
 
 =head1 ATTRIBUTES
 
