@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Command';
 use Getopt::Long qw(GetOptionsFromArray :config no_auto_abbrev no_ignore_case);
 use Mojo::Server::Daemon;
 
-has description => 'Start application with HTTP and WebSocket server.';
+has description => 'Start application with HTTP and WebSocket server';
 has usage => sub { shift->extract_usage };
 
 sub run {
@@ -43,20 +43,20 @@ Mojolicious::Command::daemon - Daemon command
     ./myapp.pl daemon -l 'https://*:443?cert=./server.crt&key=./server.key'
 
   Options:
-    -b, --backlog <size>         Listen backlog size, defaults to SOMAXCONN.
+    -b, --backlog <size>         Listen backlog size, defaults to SOMAXCONN
     -c, --clients <number>       Maximum number of concurrent clients,
-                                 defaults to 1000.
-    -g, --group <name>           Group name for process.
+                                 defaults to 1000
+    -g, --group <name>           Group name for process
     -i, --inactivity <seconds>   Inactivity timeout, defaults to the value of
-                                 MOJO_INACTIVITY_TIMEOUT or 15.
+                                 MOJO_INACTIVITY_TIMEOUT or 15
     -l, --listen <location>      One or more locations you want to listen on,
                                  defaults to the value of MOJO_LISTEN or
-                                 "http://*:3000".
+                                 "http://*:3000"
     -p, --proxy                  Activate reverse proxy support, defaults to
-                                 the value of MOJO_REVERSE_PROXY.
+                                 the value of MOJO_REVERSE_PROXY
     -r, --requests <number>      Maximum number of requests per keep-alive
-                                 connection, defaults to 25.
-    -u, --user <name>            Username for process.
+                                 connection, defaults to 25
+    -u, --user <name>            Username for process
 
 =head1 DESCRIPTION
 
@@ -77,14 +77,14 @@ L<Mojolicious::Command> and implements the following new ones.
 =head2 description
 
   my $description = $daemon->description;
-  $daemon         = $daemon->description('Foo!');
+  $daemon         = $daemon->description('Foo');
 
 Short description of this command, used for the command list.
 
 =head2 usage
 
   my $usage = $daemon->usage;
-  $daemon   = $daemon->usage('Foo!');
+  $daemon   = $daemon->usage('Foo');
 
 Usage information for this command, used for the help screen.
 
