@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Command';
 use Mojo::Loader;
 use Mojo::Util 'encode';
 
-has description => 'Inflate embedded files to real files.';
+has description => 'Inflate embedded files to real files';
 has usage => sub { shift->extract_usage };
 
 sub run {
@@ -23,7 +23,7 @@ sub run {
   }
 
   # Turn them into real files
-  for my $name (keys %all) {
+  for my $name (grep {/\.\w+$/} keys %all) {
     my $prefix = $name =~ /\.\w+\.\w+$/ ? 'templates' : 'public';
     $self->write_file($self->rel_file("$prefix/$name"), $all{$name});
   }
@@ -60,14 +60,14 @@ L<Mojolicious::Command> and implements the following new ones.
 =head2 description
 
   my $description = $inflate->description;
-  $inflate        = $inflate->description('Foo!');
+  $inflate        = $inflate->description('Foo');
 
 Short description of this command, used for the command list.
 
 =head2 usage
 
   my $usage = $inflate->usage;
-  $inflate  = $inflate->usage('Foo!');
+  $inflate  = $inflate->usage('Foo');
 
 Usage information for this command, used for the help screen.
 
