@@ -462,6 +462,9 @@ underlying connection might get closed early.
   my $address = $c->tx->remote_address;
   my $port    = $c->tx->remote_port;
 
+  # Increase size limit for WebSocket messages to 16MB
+  $c->tx->max_websocket_size(16777216) if $c->tx->is_websocket;
+
   # Perform non-blocking operation without knowing the connection status
   my $tx = $c->tx;
   Mojo::IOLoop->timer(2 => sub {
@@ -609,7 +612,7 @@ message body, in that order. If there are multiple values sharing the same
 name, and you want to access more than just the last one, you can use
 L</"every_param">. Parts of the request body need to be loaded into memory to
 parse C<POST> parameters, so you have to make sure it is not excessively
-large, there's a 10MB limit by default.
+large, there's a 16MB limit by default.
 
   # Get first value
   my $first = $c->every_param('foo')->[0];
@@ -847,8 +850,8 @@ which usually defaults to C<15> seconds.
 
 Persistent data storage for the next few requests, all session data gets
 serialized with L<Mojo::JSON> and stored Base64 encoded in HMAC-SHA1 signed
-cookies. Note that cookies usually have a C<4096> byte (4KB) limit, depending
-on browser.
+cookies, to prevent tampering. Note that cookies usually have a C<4096> byte
+(4KB) limit, depending on browser.
 
   # Manipulate session
   $c->session->{foo} = 'bar';
@@ -873,8 +876,9 @@ on browser.
 
 Access signed request cookie values and create new signed response cookies. If
 there are multiple values sharing the same name, and you want to access more
-than just the last one, you can use L</"every_signed_cookie">. Cookies failing
-HMAC-SHA1 signature verification will be automatically discarded.
+than just the last one, you can use L</"every_signed_cookie">. Cookies are
+cryptographically signed with HMAC-SHA1, to prevent tampering, and the ones
+failing signature verification will be automatically discarded.
 
 =head2 stash
 
@@ -935,7 +939,7 @@ validate C<GET> and C<POST> parameters extracted from the query string and
 C<application/x-www-form-urlencoded> or C<multipart/form-data> message body.
 Parts of the request body need to be loaded into memory to parse C<POST>
 parameters, so you have to make sure it is not excessively large, there's a
-10MB limit by default.
+16MB limit by default.
 
   my $validation = $c->validation;
   $validation->required('title')->size(3, 50);
